@@ -1,4 +1,4 @@
-from django.http import JsonResponse
+from django.http import JsonResponse, HttpResponse
 from rest_framework import request
 from rest_framework.views import APIView
 from ..services.payment_wechat_service import PaymentWechatService
@@ -41,9 +41,10 @@ class PaymentWechat(APIView):
     def callback(self):
         _xml = self.body
         wxpay_params = PaymentWechatService.callback(_xml)
+        return HttpResponse(wxpay_params)
         # return JsonResponse(wxpay_params)
-        return JsonResponse({
-            'err': 0,
-            'msg': 'OK',
-            'data': wxpay_params
-        })
+        # return JsonResponse({
+        #     'err': 0,
+        #     'msg': 'OK',
+        #     'data': wxpay_params
+        # })
