@@ -1,7 +1,7 @@
 from django.http import JsonResponse
 from rest_framework.views import APIView
 
-from xj_payment.utils import my_ali_pay
+from xj_payment.utils.utils import my_ali_pay
 
 
 class query(APIView):
