@@ -5,6 +5,8 @@ import random
 import requests
 import time
 
+import xmltodict
+from django.db import transaction
 from django.forms import model_to_dict
 from django.utils import timezone
 from lxml import etree as et
@@ -54,6 +56,11 @@ url = "https://api.mch.weixin.qq.com/v3/pay/partner/transactions/jsapi"
 logger = logging.getLogger(__name__)
 
 
+class Networkerror(Exception):
+    def __init__(self, arg):
+        self.args = arg
+
+
 class PaymentWechatService:
 
     @staticmethod
@@ -87,7 +94,7 @@ class PaymentWechatService:
             order = pay.order.create(
                 trade_type="JSAPI",  # 交易类型，小程序取值：JSAPI
                 body=description,  # 商品描述，商品简单描述
-                total_fee=int(total_fee),  # 标价金额，订单总金额，单位为分
+                total_fee=int(params['total_fee']),  # 标价金额，订单总金额，单位为分
                 notify_url=notify_url,  # 通知地址，异步接收微信支付结果通知的回调地址，通知url必须为外网可访问的url，不能携带参数。
                 sub_mch_id=sub_mch_id,
                 sub_appid=sub_appid,
@@ -159,6 +166,18 @@ class PaymentWechatService:
         # sign = calculate_sign(body, "POST", self.url, timestamp, nonce_str)
         return wxpay_params
 
+    # 微信退款
+    @staticmethod
+    def payment_refund(params):
+        pay = my_ali_pay()
+        order = pay.refund.apply(
+            total_fee=params['total_fee'],  # 订单总金额，单位为分
+            refund_fee=params['refund_fee'],  # 退款总金额，单位为分
+            out_refund_no=params['out_trade_no'],  # 商户系统内部的退款单号，商户系统内部唯一，同一退款单号多次请求只退一笔
+            out_trade_no="202210261124372361",  # 可选，微信订单号
+        )
+        return order
+
     # 小程序回调
     @staticmethod
     def callback(_xml):
@@ -192,7 +211,8 @@ class PaymentWechatService:
         try:
             if return_code == 'FAIL':
                 # 官方发出错误
-                return_dict['message'] = '支付失败'
+                return_dict['return_code'] = "SUCCESS"
+                return_dict['return_msg'] = "OK"
                 logging.error("微信支付失败")
                 # return Response(return_dict, status=status.HTTP_400_BAD_REQUEST)
             elif return_code == 'SUCCESS':
@@ -208,14 +228,21 @@ class PaymentWechatService:
                     "appid": appid
                 }
                 PaymentWechatService.payment_logic_processing(param)
-                return_dict['message'] = "支付成功"
+                return_dict['return_code'] = "SUCCESS"
+                return_dict['return_msg'] = "OK"
         except Exception as e:
             return_dict['message'] = str(e)
         finally:
-            return return_dict
+            xml_data = "<xml><return_code><![CDATA[{return_code}]]></return_code><return_msg><![CDATA[{return_msg}]]></return_msg> </xml> "
+            kw = {'return_code': 'SUCCESS', 'return_msg': 'OK'}
+            # 格式化字符串
+            xml = xml_data.format(**kw)
+            return xml
 
+    # 支付逻辑处理
     @staticmethod
     def payment_logic_processing(param):
+        sid = transaction.savepoint()
         try:
             project_name = ""
             summary = ""
@@ -231,13 +258,14 @@ class PaymentWechatService:
                 "transact_id": transaction_id,
                 "their_account_name": appid,
                 "platform": "muzpay",
-                "amount": total_amount,
+                "amount": float("-" + str(total_amount)),
                 "currency": "CNY",
                 "pay_mode": "WECHAT",
             }
             # 根据订单号查询支付记录是否存在
             payment = PaymentPayment.objects.filter(order_no=int(out_trade_no)).first()
-            print(payment)
+            if not payment:
+                logging.info("payment_callback" + "支付记录不存在")
             payment_message = model_to_dict(payment)
             finance_data['account_id'] = payment_message['user_id']
             finance_data['enroll_id'] = payment_message['enroll_id']
@@ -248,37 +276,88 @@ class PaymentWechatService:
                     # 如果存在报名id 查询报名记录
                     enroll_set, err = EnrollServices.enroll_detail(payment_message['enroll_id'])
                     if enroll_set:
+                        paid_amount = enroll_set.get("paid_amount", 0) if enroll_set.get("paid_amount", 0) else 0
                         # 报名表支付状态修改
                         enroll_data = {
-                            "enroll_status_code": "422",
-                            "paid_amount": total_amount
+                            "enroll_status_code": "43",
+                            "paid_amount": float(paid_amount) + float(total_amount),
+                            "unpaid_amount": 0
                         }
-                        enroll_data, enroll_err_txt = EnrollServices.enroll_edit(enroll_data,
-                                                                                 payment_message['enroll_id'])
+                        enroll, enroll_err_txt = EnrollServices.enroll_edit(enroll_data,
+                                                                            payment_message['enroll_id'])
                         if enroll_err_txt:
                             logging.info("payment_callback_enroll" + enroll_err_txt)
                         # 根据报名记录获取 信息模块项目基本信息
                         thread_set, err = ThreadItemService.detail(enroll_set['thread_id'])
                         if thread_set:
                             project_name = thread_set['title']
-                summary = "【" + user_set['full_name'] + "】支付 【" + project_name + "】款项"
+                summary = "【购买】：【" + user_set['full_name'] + "】支付 【" + project_name + "】款项"
             finance_data['summary'] = summary
             # # TODO 拿到订单号后的操作 看自己的业务需求
+            # 写入资金模块 （用户支付 (购买支出) ）
             funance_add_data, err_txt = FinanceTransactService.post(finance_data)
+            # 沙盒写入
+            finance_data_sand_box = {
+                "their_account_name": appid,
+                "platform": "muzpay",
+                "amount": float("-" + str(total_amount)),
+                "currency": "CNY",
+                "pay_mode": "WECHAT",
+                "summary": summary,
+                "sand_box": "镖行应付佣金",
+                'account_id': payment_message['user_id'],
+                'enroll_id': payment_message['enroll_id']
+            }
+            FinanceTransactService.post(finance_data_sand_box)
             if err_txt:
-                print(err_txt)
+                # print(err_txt)
                 logging.info("payment_callback" + err_txt)
             # 根据唯一交易id 查询主键id
-            funance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id)
-            if funance_data:
-                funance_data = model_to_dict(funance_data)
+            finance_data, err = FinanceTransactService.finance_transact_detailed(transaction_id)
+            if finance_data:
+                finance_data = model_to_dict(finance_data)
                 payment_data = {
                     "transact_no": transaction_id,
-                    "transact_id": funance_data['id'],
+                    "transact_id": finance_data['id'],
                     "order_status_id": "24"
                 }
+                # （平台的收入）
+                platform_revenue_data = {
+                    "account_id": finance_data['their_account'],
+                    "their_account_id": finance_data['account'],
+                    "enroll_id": finance_data['enroll_id'],
+                    "platform": "muzpay",
+                    "amount": float(total_amount),
+                    "summary": "【担保】：【" + user_set['full_name'] + "】支付 【" + project_name + "】款项",
+                    "currency": "CNY",
+                    "pay_mode": "BALANCE",
+                }
+                finance_platform_data_set, finance_platform_err = FinanceTransactService.post(platform_revenue_data)
+                if finance_platform_err:
+                    # print(">>>>", finance_platform_err)
+                    logging.info("payment_callback" + finance_platform_err)
+                    raise Networkerror("Bad hostname")
+                # 沙盒写入
+                platform_revenue_data_sand_box = {
+                    'transact_id': timezone.now().strftime('%Y%m%d%H%M%S') + ''.join(
+                        map(str, random.sample(range(0, 9), 4))),
+                    "account_id": finance_data['their_account'],
+                    "their_account_id": finance_data['account'],
+                    "enroll_id": finance_data['enroll_id'],
+                    "platform": "muzpay",
+                    "amount": float(total_amount),
+                    "summary": "【担保】：【" + user_set['full_name'] + "】支付 【" + project_name + "】款项",
+                    "currency": "CNY",
+                    "pay_mode": "BALANCE",
+                    'sand_box': "镖行应付佣金"
+                }
+                FinanceTransactService.post(platform_revenue_data_sand_box)
                 # 更改支付记录
                 PaymentPayment.objects.filter(order_no=int(out_trade_no)).update(**payment_data)
+        except Networkerror as t:
+            # print(t)
+            transaction.savepoint_rollback(sid)
         except Exception as e:
-            print(e)
+            # print(e)
+            transaction.savepoint_rollback(sid)
             logging.info("payment_logic_processing" + e)
