@@ -6,6 +6,7 @@ from .apis import payment_alipay
 from .apis import payment_wechat
 from .apis import payment_unionpay
 from .apis import payment
+
 app_name = 'payment'
 
 urlpatterns = [
@@ -16,7 +17,7 @@ urlpatterns = [
     # re_path(r'^get_result/?$', alipay.Payment.pay_result),  # 支付宝处理完成后同步回调通知
     re_path(r'^get_result/?$', payment_alipay.PaymentAlipay.pay_result),  # 支付宝处理完成后同步回调通知
     re_path(r'^update_order/?$', alipay.Payment.update_order),  # 支付宝处理完成后支付宝服务器异步回调通知
-    re_path(r'^refund/?$', alipay.Payment.refund),  # 支付宝退款
+    # re_path(r'^refund/?$', alipay.Payment.refund),  # 支付宝退款
     re_path(r'^close/?$', alipay.Payment.close),  # 关闭订单
 
     re_path(r'^refund_inquiry/?$', transaction_inquiry.query.refund_inquiry),  # 支付宝退款查询
@@ -33,6 +34,8 @@ urlpatterns = [
 
     re_path(r'^pay/?$', payment.Payment.pay),
 
+    re_path(r'^refund/?$', payment.Payment.refund),
+
     # re_path(r'^pay/?$', wechat_payment.WeChatPayment.pay),
     # re_path(r'^pay/?$', wechat.WeChatPayment.pay),
     # 支付结果回调
